@@ -6,7 +6,8 @@ import json
 
 from serenity_sdk.api.core import SerenityApi
 from serenity_sdk.client.raw import CallType, SerenityClient
-from serenity_types.pricing.derivatives.options.valuation import OptionValuationRequest, OptionValuationResult
+from serenity_types.pricing.derivatives.options.valuation import (
+    OptionValuationRequest, OptionValuationResult, StrategyValuationRequest, StrategyValuationResult)
 from serenity_types.pricing.derivatives.options.volsurface import (VolatilitySurfaceAvailability,
                                                                    VolatilitySurfaceVersion)
 from serenity_types.pricing.derivatives.rates.yield_curve import YieldCurveAvailability, YieldCurveVersion
@@ -34,6 +35,14 @@ class PricerApi(SerenityApi):
         raw_json = self._call_api('/derivatives/options/valuation/compute', {}, request_json, CallType.POST)
         return [OptionValuationResult.parse_obj(result) for result in raw_json['result']]
 
+    def compute_strategy_valuation(self, request: StrategyValuationRequest) -> StrategyValuationResult:
+        """
+        Calculate the value of a strategy (e.g. a spread) given a set of options and market data.
+        """
+        request_json = json.loads(request.json(exclude_unset=True, by_alias=True))
+        raw_json = self._call_api('/derivatives/strategy/valuation/compute', {}, request_json, CallType.POST)
+        return StrategyValuationResult.parse_obj(raw_json['result'])
+
     def get_volatility_surface_version(self, vol_surface_id: UUID,
                                        as_of_time: Optional[datetime] = datetime.now()) -> VolatilitySurfaceVersion:
         """
