@@ -1,6 +1,5 @@
-from datetime import date
 import json
-from typing import Any, AnyStr, Dict, List, Optional
+from typing import Any, AnyStr, Dict, Optional
 from uuid import UUID
 
 import pandas as pd
@@ -10,8 +9,8 @@ from serenity_sdk.client.raw import CallType, SerenityClient
 from serenity_sdk.types.common import STD_DATE_FMT, STD_DATETIME_FMT, CalculationContext, Portfolio
 from serenity_sdk.types.refdata import AssetMaster
 from serenity_sdk.types.factors import RiskAttributionResult
-from serenity_sdk.types.var import VaRAnalysisResult, VaRBacktestResult
-from serenity_types.risk.measures import PortfolioRiskResponse, RiskMeasureContext
+from serenity_sdk.types.measures import RiskMeasureContext
+from serenity_types.risk.measures import PortfolioRiskResponse
 
 
 class RiskApi(SerenityApi):
@@ -53,74 +52,6 @@ class RiskApi(SerenityApi):
         result = RiskAttributionResult(risk_attribution_json)
         return result
 
-    def compute_var(self, ctx: CalculationContext,
-                    portfolio: Portfolio,
-                    horizon_days: int = 1,
-                    lookback_period: int = 365,
-                    quantiles: List[float] = [95, 97.5, 99]) -> VaRAnalysisResult:
-        """
-        Uses a chosen model to compute Value at Risk (VaR) for a portfolio. Note: this API
-        currently ignores CalculationContext.model_config_id, so if you want to use a
-        different model you must set var_model to either 'VAR_PARAMETRIC_NORMAL' or
-        'VAR_HISTORICAL' -- this will be fixed in the next production upgrade.
-
-        :param ctx: the common risk calculation parameters to use, e.g. as-of date or VaR model ID
-        :param portfolio: the portfolio to test against the VaR model
-        :param horizon_days: loss forecast horizon in days , defaults to 1 day; it is used to scale single day VaR
-            by `sqrt(horizonDays)`; must be positive
-        :param lookback_period: length of risk factor time series data used to calibrate VaR, measured in days
-        :param quantiles: loss forecast quantiles used in VaR calculation; must be unique
-            and in range 0 < quantile < 100
-        :return: a typed wrapper around the VaR calculation results
-        """
-        request = {
-            **self._create_std_params(ctx.as_of_date),
-            'portfolio': {'assetPositions': portfolio.to_asset_positions()},
-            'markTime': ctx.mark_time.value,
-            'horizonDays': horizon_days,
-            'lookbackPeriod': lookback_period,
-            **self._create_var_model_params(ctx.model_config_id, lookback_period, quantiles)
-        }
-        raw_json = self._call_api('/var/compute', {}, request, CallType.POST)
-        result_json = raw_json['result']
-        result = VaRAnalysisResult._parse(result_json)
-        result.warnings = raw_json.get('warnings', [])
-        return result
-
-    def compute_var_backtest(self, ctx: CalculationContext,
-                             portfolio: Portfolio,
-                             start_date: date,
-                             end_date: date,
-                             lookback_period: int = 365,
-                             quantiles: List[float] = [95, 97.5, 99]) -> VaRBacktestResult:
-        """
-        Performs a VaR backtest, a run of the VaR model for a given portfolio over a time period.
-        The goal of the backtest to identify days where the losses exceeded the model prediction,
-        i.e. days with VaR breaches. Too many such breaches can lower confidence in the VaR model,
-        so it is an important test of the model's predictive power. Note: this API
-        currently ignores CalculationContext.model_config_id, so if you want to use a
-        different model you must set var_model to either 'VAR_PARAMETRIC_NORMAL' or
-        'VAR_HISTORICAL' -- this will be fixed in the next production upgrade.
-
-        :param ctx: the common risk calculation parameters to use, e.g. as-of date or VaR model ID
-        :param portfolio: the portfolio to test against the VaR model
-        :param start_date: the end date of the backtesting run range
-        :param end_date: the end date of the backtesting run range
-        :param lookback_period: length of risk factor time series data used to calibrate VaR, measured in days
-        :param quantiles: loss forecast quantiles used in VaR calculation; must be unique
-            and in range 0 < quantile < 100
-        :return: a typed wrapper around the VaR calculation results
-        """
-        request = {
-            'portfolio': {'assetPositions': portfolio.to_asset_positions()},
-            'startDate': start_date.strftime(STD_DATE_FMT),
-            'endDate': end_date.strftime(STD_DATE_FMT),
-            'markTime': ctx.mark_time.value,
-            **self._create_var_model_params(ctx.model_config_id, lookback_period, quantiles)
-        }
-        raw_json = self._call_api('/var/backtest', {}, request, CallType.POST)
-        return VaRBacktestResult._parse(raw_json)
-
     def compute_risk_measures(
         self, ctx: RiskMeasureContext, portfolio: Portfolio
     ) -> PortfolioRiskResponse:
@@ -245,25 +176,6 @@ class RiskApi(SerenityApi):
         factors = {factor: RiskApi._to_portfolio(indexcomps) for (factor, indexcomps) in raw_json['factors'].items()}
         return factors
 
-    def _create_var_model_params(self, model_config_id: UUID, lookback_period: int,
-                                 quantiles: List[float]) -> Dict[AnyStr, Any]:
-        """
-        VaR model parameter conventions changed between the Ricardo and Martineau releases. This method
-        takes care of rewriting both conventions to ensure backward compatiblity during the transition.
-
-        :param model_config_id: the UUID for the VaR model selected
-        :param lookback_period: the lookback period, which in Ricardo is in years, default 1, and in Martineau
-            is in days, default 365
-        :param quantiles: the list of quantiles for compute VaR or, in dev & test only, for backtest VaR as well
-        :return: a dictionary with the appropriate config keys based on environment for backward compatibility
-        """
-        params = {
-            'modelConfigId': str(model_config_id),
-            'lookbackPeriod': lookback_period,
-            'quantiles': quantiles
-        }
-        return params
-
     @staticmethod
     def _asset_matrix_to_dataframe(matrix_json: Any, asset_master: AssetMaster,
                                    portfolio: Optional[Portfolio] = None) -> pd.DataFrame:
